# LaunchDiffMode


## Enum

* `ALL` (value: `'all'`)

* `INTERSECT` (value: `'intersect'`)

* `DIFF` (value: `'diff'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


